searchNodes=[{"doc":"Utilities for dealing with Chinese characters (Hanzi) and Pinyin. This module contains several functions which deal with strings containing Han characters or Pinyin. Specifically, the following functionality is present: iex&gt; Hanyutils . to_marked_pinyin ( &quot;你好&quot; ) &quot;nǐhǎo&quot; iex&gt; Hanyutils . to_numbered_pinyin ( &quot;你好&quot; ) &quot;ni3hao3&quot; iex&gt; Hanyutils . to_zhuyin ( &quot;你好&quot; ) &quot;ㄋㄧˇㄏㄠˇ&quot; iex&gt; Hanyutils . characters? ( &quot;你好&quot; ) true iex&gt; Hanyutils . mark_pinyin ( &quot;ni3hao3&quot; ) &quot;nǐhǎo&quot; iex&gt; Hanyutils . number_pinyin ( &quot;nǐhǎo&quot; ) &quot;ni3hao3&quot; iex&gt; Hanyutils . zhuyin_to_numbered_pinyin ( &quot;ㄋㄧˇㄏㄠˇ&quot; ) &quot;ni3hao3&quot; iex&gt; Hanyutils . zhuyin_to_marked_pinyin ( &quot;ㄋㄧˇㄏㄠˇ&quot; ) &quot;nǐhǎo&quot; iex&gt; Hanyutils . pinyin_to_zhuyin ( &quot;ni3hǎo&quot; ) &quot;ㄋㄧˇㄏㄠˇ&quot; All of these functions are built based on the functionality found in the Hanzi , Pinyin and Zhuyin modules. If this module does not contain the required functionality you need, it is possible it can be built manually based on the abstractions in these modules. For instance, the to_marked_pinyin function could be implemented as follows: def to_marked_pinyin ( string ) do string |&gt; Hanzi . read ( ) |&gt; Hanzi . to_pinyin ( ) |&gt; Pinyin . marked ( ) end Please refer to the documentation of the Hanzi , Pinyin , and Zhuyin modules for more information.","ref":"Hanyutils.html","title":"Hanyutils","type":"module"},{"doc":"See Hanzi.characters?/1 .","ref":"Hanyutils.html#characters?/1","title":"Hanyutils.characters?/1","type":"function"},{"doc":"Convert a string with numbered Pinyin to marked Pinyin. Parses the input using Pinyin.read!/2 and converts the result with Pinyin.marked/1 . Please refer to the documentation of Pinyin.read/2 if you required details on how the input is parsed. If no mode is provided, :words mode is used by default. Examples iex&gt; Hanyutils . mark_pinyin ( &quot;ni3hǎo&quot; ) &quot;nǐhǎo&quot;","ref":"Hanyutils.html#mark_pinyin/2","title":"Hanyutils.mark_pinyin/2","type":"function"},{"doc":"Convert a string with marked Pinyin to numbered Pinyin. Parses the input using Pinyin.read!/2 , and converts the result with Pinyin.numbered/1 . Please refer to the documentation of Pinyin.read/2 if you require details on how the input is parsed. It is worth noting that the Pinyin.read/2 parser is sensitive to the location of the tone marker. Pinyin.read!/2 is called in :words mode if no mode is provided. Examples iex&gt; Hanyutils . number_pinyin ( &quot;ni3hǎo&quot; ) &quot;ni3hao3&quot;","ref":"Hanyutils.html#number_pinyin/2","title":"Hanyutils.number_pinyin/2","type":"function"},{"doc":"Convert a string with Pinyin to Zhuyin Parses the input using Pinyin.read!/2 , and converts the result with Zhuyin.from_pinyin/1 . Please refer to the documentation of Pinyin.read/2 if you require details on how the input is parsed. It is worth noting that the Pinyin.read/2 parser is sensitive to the location of the tone marker. Pinyin.read!/2 is called in :words mode if no mode is provided. Examples iex&gt; Hanyutils . pinyin_to_zhuyin ( &quot;ni3hǎo&quot; ) &quot;ㄋㄧˇㄏㄠˇ&quot; iex&gt; Hanyutils . pinyin_to_zhuyin ( &quot;zhu1yu3chen2&quot; ) &quot;ㄓㄨㄩˇㄔㄣˊ&quot;","ref":"Hanyutils.html#pinyin_to_zhuyin/2","title":"Hanyutils.pinyin_to_zhuyin/2","type":"function"},{"doc":"Convert a string containing Han characters to marked Pinyin. For more information about converter , please refer to Hanzi.to_pinyin/2 . Examples iex&gt; Hanyutils . to_marked_pinyin ( &quot;你好&quot; ) &quot;nǐhǎo&quot; iex&gt; Hanyutils . to_marked_pinyin ( &quot;你好&quot; , &amp; Hanzi . all_pronunciations / 1 ) &quot;nǐ[ hǎo | hào ]&quot;","ref":"Hanyutils.html#to_marked_pinyin/2","title":"Hanyutils.to_marked_pinyin/2","type":"function"},{"doc":"Convert a string containing Han characters to numbered Pinyin. For more information about converter , please refer to Hanzi.to_pinyin/2 . Examples iex&gt; Hanyutils . to_numbered_pinyin ( &quot;你好&quot; ) &quot;ni3hao3&quot; iex&gt; Hanyutils . to_numbered_pinyin ( &quot;你好&quot; , &amp; Hanzi . all_pronunciations / 1 ) &quot;ni3[ hao3 | hao4 ]&quot;","ref":"Hanyutils.html#to_numbered_pinyin/2","title":"Hanyutils.to_numbered_pinyin/2","type":"function"},{"doc":"Convert a string containing Han characters to Zhuyin. Because the Unihan database only provides information about pinyin pronunciations, we convert the Han characters to pinyin (using Hanzi.to_pinyin/2 ), after which we convert the generated pinyin to zhuyin. The documentation of Hanzi.to_pinyin/2 contains additional information about the converter argument. Examples iex&gt; Hanyutils . to_zhuyin ( &quot;你好&quot; ) &quot;ㄋㄧˇㄏㄠˇ&quot; iex&gt; Hanyutils . to_zhuyin ( &quot;朱宇辰&quot; ) &quot;ㄓㄨㄩˇㄔㄣˊ&quot; iex&gt; Hanyutils . to_zhuyin ( &quot;你好&quot; , &amp; Hanzi . all_pronunciations / 1 ) &quot;ㄋㄧˇ[ ㄏㄠˇ | ㄏㄠˋ ]&quot;","ref":"Hanyutils.html#to_zhuyin/2","title":"Hanyutils.to_zhuyin/2","type":"function"},{"doc":"Convert a string with Zhuyin to marked Pinyin. Parses the input using Zhuyin.read!/2 , and converts the result with Pinyin.numbered/1 . Please refer to the documentation of Zhuyin.read/2 if you require details on how the input is parsed or on the mode argument. Zhuyin.read!/2 is called in :words mode if no mode is provided. Examples iex&gt; Hanyutils . zhuyin_to_marked_pinyin ( &quot;ㄋㄧˇㄏㄠˇ&quot; ) &quot;nǐhǎo&quot; iex&gt; Hanyutils . zhuyin_to_marked_pinyin ( &quot;ㄓㄨㄩˇㄔㄣˊ&quot; ) &quot;zhūyǔchén&quot;","ref":"Hanyutils.html#zhuyin_to_marked_pinyin/2","title":"Hanyutils.zhuyin_to_marked_pinyin/2","type":"function"},{"doc":"Convert a string with Zhuyin to numbered Pinyin. Parses the input using Zhuyin.read!/2 , and converts the result with Pinyin.numbered/1 . Please refer to the documentation of Zhuyin.read/2 if you require information on how the input is parsed or on the mode argument. Zhuyin.read!/2 is called in :words mode if no mode is provided. Examples iex&gt; Hanyutils . zhuyin_to_numbered_pinyin ( &quot;ㄋㄧˇㄏㄠˇ&quot; ) &quot;ni3hao3&quot; iex&gt; Hanyutils . zhuyin_to_numbered_pinyin ( &quot;ㄓㄨㄩˇㄔㄣˊ&quot; ) &quot;zhu1yu3chen2&quot;","ref":"Hanyutils.html#zhuyin_to_numbered_pinyin/2","title":"Hanyutils.zhuyin_to_numbered_pinyin/2","type":"function"},{"doc":"Han/Chinese character (汉字) utilities and conversion to Pinyin lists. The main goal of this module is to convert strings containing Han characters into a Pinyin.pinyin_list/0 . In turn, such a list can be formatted by the functions present in the Pinyin module (i.e. Pinyin.marked/1 or Pinyin.numbered/1 ). A string of Han characters can be read with read/1 or sigil_h/2 . These functions both return a list containing strings mixed with Hanzi.t/0 structs. Such a list can be converted into a Pinyin.pinyin_list/0 through the use of to_pinyin/2 . Users with more esoteric use cases can directly modify the Hanzi.t/0 inside the hanzi_list/0 . to_pinyin/2 and converters Since a given Hanzi may have different valid pronunciations, to_pinyin/2 accepts a second argument that determines how a given Hanzi.t/0 is converted into a Pinyin.pinyin_list/0 . This second argument is called a converter . This module includes some standard converters. Please refer to the documentation of to_pinyin/2 for more information. Data source The results of the functions offered by this module are all ultimately derived from the data contained in the Unihan_Readings.txt file of the Unicode Han Database . t/0 contains additional information about the available information.","ref":"Hanzi.html","title":"Hanzi","type":"module"},{"doc":"Converter that returns all pronunciations of a character or the most common. If only a single pronunciation is available, it is returned, otherwise, all possible pronunciations are returned. When all possible pronunciations are returned, left , mid and right determine how the alternatives are separated. left is positioned before the first pronunciation in the list, right is positioned after the last pronunciation, mid is positioned between all the other pronunciations. Examples iex&gt; Hanzi . all_pronunciations ( ~h/你/s ) [ % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } ] iex&gt; Hanzi . all_pronunciations ( ~h/㓎/s ) [ &quot;[ &quot; , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 1 } , &quot; | &quot; , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 4 } , &quot; | &quot; , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 3 } , &quot; ]&quot; ] iex&gt; Hanzi . all_pronunciations ( ~h/㓎/s , &quot;&quot; , &quot;&quot; , &quot;&quot; ) [ &quot;&quot; , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 1 } , &quot;&quot; , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 4 } , &quot;&quot; , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 3 } , &quot;&quot; ]","ref":"Hanzi.html#all_pronunciations/4","title":"Hanzi.all_pronunciations/4","type":"function"},{"doc":"Check if a single character is a valid Han character. Examples iex&gt; Hanzi . character? ( &quot;你&quot; ) true iex&gt; Hanzi . character? ( &quot;x&quot; ) false iex&gt; Hanzi . character? ( &quot;你好&quot; ) false","ref":"Hanzi.html#character?/1","title":"Hanzi.character?/1","type":"function"},{"doc":"Convert a Hanzi list to a string of characters. This function extracts the character of each Hanzi.t/0 in lst . Normal strings in the list not modified. After converting the Hanzi in the list to characters, the list is joined with Enum.join/2 . The joiner argument will be passed as the joiner to Enum.join/2 . Examples iex&gt; characters ( ~h/你好/ ) &quot;你好&quot; iex&gt; characters ( ~h/你hello/ ) &quot;你hello&quot; iex&gt; characters ( ~h/你好/ , &quot;;&quot; ) &quot;你;好&quot; iex&gt; characters ( ~h/你hello/ , &quot;;&quot; ) &quot;你;hello&quot;","ref":"Hanzi.html#characters/2","title":"Hanzi.characters/2","type":"function"},{"doc":"Verify if a list or string contains only characters. Note that whitespace is not counted as a character. Examples iex&gt; Hanzi . characters? ( [ &quot;你&quot; , &quot;好&quot; ] ) true iex&gt; Hanzi . characters? ( [ &quot;你&quot; , &quot;boo&quot; , &quot;好&quot; ] ) false iex&gt; Hanzi . characters? ( &quot;你好&quot; ) true iex&gt; Hanzi . characters? ( &quot;你 好&quot; ) false","ref":"Hanzi.html#characters?/1","title":"Hanzi.characters?/1","type":"function"},{"doc":"Converter that retrieves the most common pronunciation of a Hanzi.t/0 . The additional argument specifies if the most common pronunciation for mainland China or Taiwan is retrieved. Examples iex&gt; Hanzi . common_pronunciation ( ~h/你/s ) [ % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } ] iex&gt; Hanzi . common_pronunciation ( ~h/你/s , :cn ) [ % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } ] iex&gt; Hanzi . common_pronunciation ( ~h/你/s , :tw ) [ % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } ] iex&gt; Hanzi . common_pronunciation ( ~h/万/s ) [ % Pinyin { initial : &quot;&quot; , final : &quot;wan&quot; , tone : 4 } ] iex&gt; Hanzi . common_pronunciation ( ~h/万/s , :cn ) [ % Pinyin { initial : &quot;&quot; , final : &quot;wan&quot; , tone : 4 } ] iex&gt; Hanzi . common_pronunciation ( ~h/万/s , :tw ) [ % Pinyin { initial : &quot;m&quot; , final : &quot;o&quot; , tone : 4 } ]","ref":"Hanzi.html#common_pronunciation/2","title":"Hanzi.common_pronunciation/2","type":"function"},{"doc":"Obtain the Hanzi.t/0 struct for a character. Note that this only works on a single character. Examples iex&gt; Hanzi . from_character ( &quot;你&quot; ) % Hanzi { char : &quot;你&quot; , pron : % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } , pron_tw : nil , alt : [ ] } iex&gt; Hanzi . from_character ( &quot;x&quot; ) nil iex&gt; Hanzi . from_character ( &quot;你好&quot; ) nil","ref":"Hanzi.html#from_character/1","title":"Hanzi.from_character/1","type":"function"},{"doc":"Converter that returns a list of all known pronunciations of a character. This converter is similar to all_pronunciations/4 , but it does not include separators around the various pronunciations. Examples iex&gt; Hanzi . list_pronunciations ( ~h/你/s ) [ % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } ] iex&gt; Hanzi . list_pronunciations ( ~h/㓎/s ) [ % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 1 } , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 4 } , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 3 } ] iex&gt; Hanzi . list_pronunciations ( ~h/㓎/s ) [ % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 1 } , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 4 } , % Pinyin { initial : &quot;q&quot; , final : &quot;in&quot; , tone : 3 } ]","ref":"Hanzi.html#list_pronunciations/1","title":"Hanzi.list_pronunciations/1","type":"function"},{"doc":"Read a string and convert it into a list of strings and Hanzi.t/0 structs. This function reads a string containing characters mixed with normal text. The output of this function is a list of strings and Hanzi structs. The input string may contain any character. Any character in the string that is recognised as a Han character (by character?/1 ) is returned as a Hanzi.t/0 in the returned list. Any other character in the input is returned unmodified. Examples iex&gt; Hanzi . read ( &quot;你好&quot; ) [ % Hanzi { char : &quot;你&quot; , pron : % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } } , % Hanzi { char : &quot;好&quot; , pron : % Pinyin { initial : &quot;h&quot; , final : &quot;ao&quot; , tone : 3 } , alt : [ % Pinyin { initial : &quot;h&quot; , final : &quot;ao&quot; , tone : 3 } , % Pinyin { initial : &quot;h&quot; , final : &quot;ao&quot; , tone : 4 } ] } ] iex&gt; Hanzi . read ( &quot;hello, 你&quot; ) [ &quot;hello, &quot; , % Hanzi { char : &quot;你&quot; , pron : % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } } ]","ref":"Hanzi.html#read/1","title":"Hanzi.read/1","type":"function"},{"doc":"Sigil to create a Hanzi list or struct. When used without any modifiers, this sigil converts ins input into a hanzi list through the use of read/1 . When the s modifier is used, from_character/1 is used instead. Examples iex&gt; ~h/hello, 你/ [ &quot;hello, &quot; , % Hanzi { char : &quot;你&quot; , pron : % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } } ] iex&gt; ~h/你/s % Hanzi { char : &quot;你&quot; , pron : % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } } iex&gt; ~h/你好/s nil","ref":"Hanzi.html#sigil_h/2","title":"Hanzi.sigil_h/2","type":"macro"},{"doc":"Convert a Hanzi list to a Pinyin list. Normal strings in the Hanzi list are returned unmodified. Every Hanzi.t() is passed as an argument to converter , which returns a Pinyin.pinyin_list/0 . This list is added to the result. After calling this function, Pinyin.marked/1 or Pinyin.numbered/1 can be used to format the result. Converters A converter is any function that transforms a Hanzi.t/0 into a Pinyin.pinyin_list/0 . In the most simple case, such a converter simply returns the most common pronunciation. In more complicated cases, such a converter returns all the possible pronunciations of a Hanzi, separated by strings. The Hanzi module includes two converters: common_pronunciation/2 and all_pronunciations/4 . If no converter is specified, &amp;common_pronunciation(&amp;1, :cn) is used. If you wish to write your own converter, the functions mentioned above, and the examples below should be a good starting point. Examples iex&gt; to_pinyin ( ~h/你好/ ) [ % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } , % Pinyin { initial : &quot;h&quot; , final : &quot;ao&quot; , tone : 3 } ] iex&gt; to_pinyin ( ~h/二万/ , &amp; common_pronunciation ( &amp;1 , :tw ) ) [ % Pinyin { initial : &quot;&quot; , final : &quot;er&quot; , tone : 4 } , % Pinyin { initial : &quot;m&quot; , final : &quot;o&quot; , tone : 4 } ] iex&gt; to_pinyin ( ~h/你好/ , &amp; all_pronunciations / 1 ) [ % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } , &quot;[ &quot; , % Pinyin { initial : &quot;h&quot; , final : &quot;ao&quot; , tone : 3 } , &quot; | &quot; , % Pinyin { initial : &quot;h&quot; , final : &quot;ao&quot; , tone : 4 } , &quot; ]&quot; ] iex&gt; to_pinyin ( ~h/你好/ , &amp; all_pronunciations ( &amp;1 , &quot;&quot; , &quot;&quot; , &quot;&quot; ) ) [ % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } , &quot;&quot; , % Pinyin { initial : &quot;h&quot; , final : &quot;ao&quot; , tone : 3 } , &quot;&quot; , % Pinyin { initial : &quot;h&quot; , final : &quot;ao&quot; , tone : 4 } , &quot;&quot; ] iex&gt; to_pinyin ( ~h/你好/ , fn % Hanzi { pron : p } -&gt; [ p ] end ) [ % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } , % Pinyin { initial : &quot;h&quot; , final : &quot;ao&quot; , tone : 3 } ]","ref":"Hanzi.html#to_pinyin/2","title":"Hanzi.to_pinyin/2","type":"function"},{"doc":"List of Hanzi characters mixed with plain strings.","ref":"Hanzi.html#t:hanzi_list/0","title":"Hanzi.hanzi_list/0","type":"type"},{"doc":"Representation of a single Hanzi (chinese Character). This struct contains all the information extraced from the Unihan_readings database for a given character. It contains the following fields: Key Description Unihan_Readings.txt field char The character itself pron Most common pronunciation in pinyin kMandarin pron_tw Most common pronunciation for Taiwan in Pinyin kMandarin alt All readings defined by the Hanyu Pinyin Dictionary kHanyuPinyin pron and pron_tw In some rare cases, the most common reading of a hanzi is different in mainland China and in Taiwan. If this is the case, the most common mainland reading will be stored under the pron key, while the most common Taiwanese reading will be stored under the pron_tw key. When the readings are the same, pron will contain the reading while pron_tw will be nil . Note that, at the time of writing, only 38 characters out of the 41226 defined by Unihan_Readings.txt have a different reading for mainland China and Taiwan. alt Some hanzi have different readings based on their exact use. When this is the case, all the possible readings of a character will stored as a list in alt .","ref":"Hanzi.html#t:t/0","title":"Hanzi.t/0","type":"type"},{"doc":"Utilities to deal with pinyin syllables and groups thereof. The main goal of this module is to provide functions to manipulate strings that contain pinyin words, which are potentially mixed with other content. These strings are represented by the pinyin_list/0 type. Pinyin lists can be obtained by parsing a string with the read/2 , read!/2 or sigil_p/2 functions, or by using Hanzi.to_pinyin/2 . Afterwards, these lists can be converted into a numbered or marked_ representation by using the numbered/1 or marked/1 function, respectively. A pinyin_list/0 is a list which contains strings and pinyin structs ( t/0 ). These structs are used to encode pinyin syllables; they can be created directly through the use of the from_marked/1 , from_marked!/1 , from_numbered/1 , from_numbered!/1 , from_string/1 or from_string!/1 functions. Like t:pinyin_lists/0 , t/0 structs can be converted to numbered or marked strings through the use of the numbered/1 and marked/1 functions.","ref":"Pinyin.html","title":"Pinyin","type":"module"},{"doc":"Create a single pinyin struct ( t/0 ) from a string with tone marks. This function can only be used to parse a single pinyin syllable (e.g. &quot;nǐ&quot;, not &quot;nǐhǎo&quot;). If parsing fails, an {:error, &lt;remainder of string&gt;} is returned, &lt;remainder of string&gt; contains the part of the string which made parsing fail. Examples iex&gt; Pinyin . from_marked ( &quot;nǐ&quot; ) { :ok , % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } } iex&gt; Pinyin . from_marked ( &quot;nǐhǎo&quot; ) { :error , &quot;hǎo&quot; } iex&gt; Pinyin . from_marked ( &quot;hello&quot; ) { :error , &quot;llo&quot; }","ref":"Pinyin.html#from_marked/1","title":"Pinyin.from_marked/1","type":"function"},{"doc":"Create a single pinyin struct ( t/0 ) from a string with tone marks. Like from_marked/1 , but returns the result or raises an exception if an error occurred while parsing. Examples iex&gt; Pinyin . from_marked! ( &quot;nǐ&quot; ) # Pinyin &lt; nǐ &gt; iex&gt; Pinyin . from_marked! ( &quot;nǐhǎo&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;hǎo&quot; iex&gt; Pinyin . from_marked! ( &quot;hello&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;llo&quot;","ref":"Pinyin.html#from_marked!/1","title":"Pinyin.from_marked!/1","type":"function"},{"doc":"Create a single pinyin struct ( t/0 ) from a string with a tone number. This function can only be used to parse a single pinyin syllable (e.g. &quot;ni3&quot;, not &quot;ni3hao3&quot;), no whitespace may be present between the pinyin syllable and the tone marker. The tone marker should be a number between 1 and 4 and the last element of the string. If parsing fails, an {:error, &lt;remainder of string&gt;} is returned, &lt;remainder of string&gt; contains the part of the string which made parsing fail. Examples iex&gt; Pinyin . from_numbered ( &quot;ni3&quot; ) { :ok , % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } } iex&gt; Pinyin . from_numbered ( &quot;ni3hao3&quot; ) { :error , &quot;hao3&quot; } iex&gt; Pinyin . from_numbered ( &quot;ha3o&quot; ) { :error , &quot;o&quot; } iex&gt; Pinyin . from_numbered ( &quot;hello&quot; ) { :error , &quot;llo&quot; }","ref":"Pinyin.html#from_numbered/1","title":"Pinyin.from_numbered/1","type":"function"},{"doc":"Create a single pinyin struct ( t/0 ) from a string with a tone number. Like from_numbered/1 , but returns the result or raises an exception if an error occurred while parsing. Examples iex&gt; Pinyin . from_numbered! ( &quot;ni3&quot; ) # Pinyin &lt; nǐ &gt; iex&gt; Pinyin . from_numbered! ( &quot;ni3hao3&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;hao3&quot; iex&gt; Pinyin . from_numbered! ( &quot;ha3o&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;o&quot; iex&gt; Pinyin . from_numbered! ( &quot;hello&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;llo&quot;","ref":"Pinyin.html#from_numbered!/1","title":"Pinyin.from_numbered!/1","type":"function"},{"doc":"Create a single pinyin struct ( t/0 ) from a string. This function can be used to parse a single pinyin syllable which is marked or which has a tone number. It combines the functionality of from_marked/1 and from_numbered/1 .The limitations of these functions apply to this function. If parsing fails, an {:error, &lt;remainder of string&gt;} is returned, &lt;remainder of string&gt; contains the part of the string which made parsing fail. Examples iex&gt; Pinyin . from_string ( &quot;ni3&quot; ) { :ok , % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } } iex&gt; Pinyin . from_string ( &quot;nǐ&quot; ) { :ok , % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } } iex&gt; Pinyin . from_string ( &quot;ni3hao3&quot; ) { :error , &quot;hao3&quot; } iex&gt; Pinyin . from_string ( &quot;nǐhǎo&quot; ) { :error , &quot;hǎo&quot; }","ref":"Pinyin.html#from_string/1","title":"Pinyin.from_string/1","type":"function"},{"doc":"Create a single pinyin struct ( t/0 ) from a string. Like from_string/1 , but returns the result or raises an exception if an error occurred while parsing. Examples iex&gt; Pinyin . from_string! ( &quot;ni3&quot; ) # Pinyin &lt; nǐ &gt; iex&gt; Pinyin . from_string! ( &quot;nǐ&quot; ) # Pinyin &lt; nǐ &gt; iex&gt; Pinyin . from_string! ( &quot;ni3hao3&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;hao3&quot; iex&gt; Pinyin . from_string! ( &quot;nǐhǎo&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;hǎo&quot;","ref":"Pinyin.html#from_string!/1","title":"Pinyin.from_string!/1","type":"function"},{"doc":"Convert a t/0 or pinyin_list/0 to a tone-marked string. The tone-marked string consists of the pinyin word with the tone added in the correct location. It is generally used when printing pinyin. Any occurence of &quot;v&quot; is shown as &quot;ü&quot;. Examples iex&gt; marked ( ~p/ni3/s ) &quot;nǐ&quot; iex&gt; marked ( ~p/lve4/s ) &quot;lüè&quot; iex&gt; marked ( ~p/ni3hao3/ ) &quot;nǐhǎo&quot; iex&gt; marked ( ~p/NI3HAO3/ ) &quot;NǏHǍO&quot; iex&gt; marked ( ~p/Ni3hao3, how are you?/w ) &quot;Nǐhǎo, how are you?&quot;","ref":"Pinyin.html#marked/1","title":"Pinyin.marked/1","type":"function"},{"doc":"Convert a t/0 or pinyin_list/0 to a numbered version. The numbered version consists of the word without tone markings followed by the number of the tone. It is often used when typing pinyin manually. Any occurence of &quot;ü&quot; is shown as &quot;v&quot;. Non-pinyin text is not modified. Examples iex&gt; numbered ( ~p/nǐ/s ) &quot;ni3&quot; iex&gt; numbered ( ~p/lüè/s ) &quot;lve4&quot; iex&gt; numbered ( ~p/nǐhǎo/ ) &quot;ni3hao3&quot; iex&gt; numbered ( ~p/NǏHǍO/ ) &quot;NI3HAO3&quot; iex&gt; numbered ( ~p/Nǐhǎo, how are you?/w ) &quot;Ni3hao3, how are you?&quot;","ref":"Pinyin.html#numbered/1","title":"Pinyin.numbered/1","type":"function"},{"doc":"Read a string and convert it into a list of string and pinyin structs. This function reads a string containing pinyin mixed with normal text. The output of this function is a list of strings and pinyin structs. White space and punctuation will be separated from other strings. The input string may contain tone-marked (e.g. &quot;nǐ&quot;) pinyin, numbered (&quot;ni3&quot;) pinyin or a mix thereof (nǐ hao3). Note that in numbered pinyin mode tone numerals must not be separated from their word. For instance, &quot;ni3&quot; will be correctly parsed as &quot;nǐ&quot;, &quot;ni 3&quot; will not. When tone marked pinyin is used the tone must be marked on the correct letter. For instance, hǎo will parse correctly, haǒ will not; we recommend the use of numbered pinyin if there is uncertainty about the location of the tone mark. Parse Modes By default, this function only accepts strings which consists exclusively of pinyin, whitespace and punctuation. Parsing any text that cannot be interpreted as pinyin will result in an error: iex&gt; Pinyin . read ( &quot;Ni3hao3!&quot; ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;!&quot; ] } iex&gt; Pinyin . read ( &quot;Ni3hao3, hello!&quot; ) { :error , &quot;hello!&quot; } This behaviour can be tweaked if pinyin mixed with regular text needs to be parsed; this can be done by passing a mode to this function. There are 3 available modes: :exclusive : The default. Every character (except white space and punctuation) is interpreted as pinyin. If this is not possible, an error is returned. :words : Any word (i.e. a continuous part of the string that does not contain whitespace or punctuation) is either interpreted as a sequence of pinyin syllables or as non-pinyin text. If a word contains any characters that cannot be interpreted as pinyin, the whole word is considered to be non-pinyin text. This mode does not return errors. :mixed : Any word can contain a mixture of pinyin and non-pinyin characters. The read function will interpret anything it can interpret as pinyin as pinyin and leaves the other text unmodified. This is mainly useful to mix characters and pinyin. It is recommend to use the :words mode when possible instead of this mode, as this mode will often parse regular text as pinyin text. This mode does not return errors. The following examples show the use of all three modes: iex&gt; Pinyin . read ( &quot;Ni3hao3!&quot; , :exclusive ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;!&quot; ] } iex&gt; Pinyin . read ( &quot;Ni3hao3, hello!&quot; , :exclusive ) { :error , &quot;hello!&quot; } iex&gt; Pinyin . read ( &quot;Ni3好hao3, hello!&quot; , :exclusive ) { :error , &quot;Ni3好hao3, hello!&quot; } iex&gt; Pinyin . read ( &quot;Ni3hao3!&quot; , :words ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;!&quot; ] } iex&gt; Pinyin . read ( &quot;Ni3hao3, hello!&quot; , :words ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Pinyin . read ( &quot;Ni3好hao3, hello!&quot; , :words ) { :ok , [ &quot;Ni3好hao3&quot; , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Pinyin . read ( &quot;Ni3hao3!&quot; , :mixed ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;!&quot; ] } iex&gt; Pinyin . read ( &quot;Ni3hao3, hello!&quot; , :mixed ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;, &quot; , % Pinyin { initial : &quot;h&quot; , final : &quot;e&quot; } , &quot;l&quot; , % Pinyin { initial : &quot;l&quot; , final : &quot;o&quot; } , &quot;!&quot; ] } iex&gt; Pinyin . read ( &quot;Ni3好hao3, hello!&quot; , :mixed ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , &quot;好&quot; , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;, &quot; , % Pinyin { initial : &quot;h&quot; , final : &quot;e&quot; } , &quot;l&quot; , % Pinyin { initial : &quot;l&quot; , final : &quot;o&quot; } , &quot;!&quot; ] } When :mixed or :word mode is used, it is possible some words are incorrectly identified as pinyin. This is generally not a problem for users who just wish to use marked/1 or numbered/1 on the result of read/2 , since pinyin syllables with no tone are printed as is. Capitalization and -r suffix This function is able to read capitalized and uppercase pinyin strings. That is, strings such as &quot;Ni3hao3&quot;, &quot;NI3HAO3&quot; and &quot;NI3hao3&quot; are accepted. However, pinyin words with mixed capitalization are not recognized: iex&gt; Pinyin . read ( &quot;Lei3&quot; ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;L&quot; , final : &quot;ei&quot; } ] } iex&gt; Pinyin . read ( &quot;LEI3&quot; ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;L&quot; , final : &quot;EI&quot; } ] } iex&gt; Pinyin . read ( &quot;LeI&quot; ) { :error , &quot;LeI&quot; } iex&gt; Pinyin . read ( &quot;LEi&quot; ) { :error , &quot;LEi&quot; } Finally, this function does not detect the -r suffix. Users of the library should take care to fully write out er instead. That is, do not write &quot;zher&quot;, use &quot;zheer&quot; instead. iex&gt; Pinyin . read ( &quot;zher&quot; ) { :error , &quot;zher&quot; } iex&gt; Pinyin . read ( &quot;zheer&quot; ) { :ok , [ % Pinyin { initial : &quot;zh&quot; , final : &quot;e&quot; } , % Pinyin { initial : &quot;&quot; , final : &quot;er&quot; } ] }","ref":"Pinyin.html#read/2","title":"Pinyin.read/2","type":"function"},{"doc":"Identical to read/2 , but returns the result or a ParseError Examples iex&gt; Pinyin . read! ( &quot;ni3hao3&quot; ) [ % Pinyin { tone : 3 , initial : &quot;n&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } ] iex&gt; Pinyin . read! ( &quot;ni3 hao3&quot; ) [ % Pinyin { tone : 3 , initial : &quot;n&quot; , final : &quot;i&quot; } , &quot; &quot; , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } ] iex&gt; Pinyin . read! ( &quot;ni 3&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;3&quot;","ref":"Pinyin.html#read!/2","title":"Pinyin.read!/2","type":"function"},{"doc":"Read a string containing marked pinyin and convert it into pinyin_list/0 . Like read/2 , but only accepts marked pinyin. Examples iex&gt; Pinyin . read_marked ( &quot;Nǐhǎo!&quot; , :exclusive ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;!&quot; ] } iex&gt; Pinyin . read_marked ( &quot;Nǐhǎo, hello!&quot; , :exclusive ) { :error , &quot;hello!&quot; } iex&gt; Pinyin . read_marked ( &quot;Ni3hao3, hello!&quot; , :exclusive ) { :error , &quot;Ni3hao3, hello!&quot; } iex&gt; Pinyin . read_marked ( &quot;Nǐhǎo, hello!&quot; , :words ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Pinyin . read_marked ( &quot;Ni3hao3, hello!&quot; , :words ) { :ok , [ &quot;Ni3hao3&quot; , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Pinyin . read_marked ( &quot;Ni3hǎo, hello!&quot; , :words ) { :ok , [ &quot;Ni3hǎo&quot; , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Pinyin . read_marked ( &quot;Ni3hao3!&quot; , :mixed ) { :ok , [ % Pinyin { tone : 0 , initial : &quot;N&quot; , final : &quot;i&quot; } , &quot;3&quot; , % Pinyin { tone : 0 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;3&quot; , &quot;!&quot; ] } iex&gt; Pinyin . read_marked ( &quot;Ni3hǎo, hello!&quot; , :mixed ) { :ok , [ % Pinyin { tone : 0 , initial : &quot;N&quot; , final : &quot;i&quot; } , &quot;3&quot; , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;, &quot; , % Pinyin { initial : &quot;h&quot; , final : &quot;e&quot; } , &quot;l&quot; , % Pinyin { initial : &quot;l&quot; , final : &quot;o&quot; } , &quot;!&quot; ] }","ref":"Pinyin.html#read_marked/2","title":"Pinyin.read_marked/2","type":"function"},{"doc":"Identical to read_marked/2 , but returns the result or a ParseError Examples iex&gt; Pinyin . read_marked! ( &quot;nǐhǎo&quot; ) [ % Pinyin { tone : 3 , initial : &quot;n&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } ] iex&gt; Pinyin . read_marked! ( &quot;ni3 hao3&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;ni3 hao3&quot;","ref":"Pinyin.html#read_marked!/2","title":"Pinyin.read_marked!/2","type":"function"},{"doc":"Read a string containing numbered pinyin and convert it into pinyin_list/0 . Like read/2 , but only accepts numbered pinyin. Examples iex&gt; Pinyin . read_numbered ( &quot;Ni3hao3!&quot; , :exclusive ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;!&quot; ] } iex&gt; Pinyin . read_numbered ( &quot;Ni3hao3, hello!&quot; , :exclusive ) { :error , &quot;hello!&quot; } iex&gt; Pinyin . read_numbered ( &quot;Nǐhǎo, hello!&quot; , :exclusive ) { :error , &quot;Nǐhǎo, hello!&quot; } iex&gt; Pinyin . read_numbered ( &quot;Ni3hao3, hello!&quot; , :words ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Pinyin . read_numbered ( &quot;Nǐhǎo, hello!&quot; , :words ) { :ok , [ &quot;Nǐhǎo&quot; , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Pinyin . read_numbered ( &quot;Ni3hǎo, hello!&quot; , :words ) { :ok , [ &quot;Ni3hǎo&quot; , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Pinyin . read_numbered ( &quot;Ni3hǎo!&quot; , :mixed ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , &quot;hǎ&quot; , % Pinyin { final : &quot;o&quot; } , &quot;!&quot; ] } iex&gt; Pinyin . read_numbered ( &quot;Ni3hǎo, hello!&quot; , :mixed ) { :ok , [ % Pinyin { tone : 3 , initial : &quot;N&quot; , final : &quot;i&quot; } , &quot;hǎ&quot; , % Pinyin { final : &quot;o&quot; } , &quot;, &quot; , % Pinyin { initial : &quot;h&quot; , final : &quot;e&quot; } , &quot;l&quot; , % Pinyin { initial : &quot;l&quot; , final : &quot;o&quot; } , &quot;!&quot; ] }","ref":"Pinyin.html#read_numbered/2","title":"Pinyin.read_numbered/2","type":"function"},{"doc":"Identical to read_numbered/2 , but returns the result or a ParseError Examples iex&gt; Pinyin . read_numbered! ( &quot;ni3hao3&quot; ) [ % Pinyin { tone : 3 , initial : &quot;n&quot; , final : &quot;i&quot; } , % Pinyin { tone : 3 , initial : &quot;h&quot; , final : &quot;ao&quot; } ] iex&gt; Pinyin . read_numbered! ( &quot;nǐhǎo&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;nǐhǎo&quot;","ref":"Pinyin.html#read_numbered!/2","title":"Pinyin.read_numbered!/2","type":"function"},{"doc":"Sigil to create a pinyin list or struct. When used without any modifiers, this sigil converts its input into a pinyin list through the use of read!/2 in :exclusive mode. The w and m modifiers can be used to use :words or :mixed mode respectively. When this sigil is called with the s modifier, a pinyin struct is created by calling from_string!/1 . Examples iex&gt; ~p/ni3/ [ % Pinyin { tone : 3 , initial : &quot;n&quot; , final : &quot;i&quot; } ] iex&gt; ~p/ni3 hello/w [ % Pinyin { tone : 3 , initial : &quot;n&quot; , final : &quot;i&quot; } , &quot; &quot; , &quot;hello&quot; ] iex&gt; ~p/ni3好/m [ % Pinyin { tone : 3 , initial : &quot;n&quot; , final : &quot;i&quot; } , &quot;好&quot; ] iex&gt; ~p/ni3/s % Pinyin { tone : 3 , initial : &quot;n&quot; , final : &quot;i&quot; }","ref":"Pinyin.html#sigil_p/2","title":"Pinyin.sigil_p/2","type":"macro"},{"doc":"List of pinyin syllables mixed with plain strings. An instance of this type can be created from a string containing Han characters with the Hanzi.to_pinyin/2 function. Alternatively, the read/2 or read!/2 functions can be used to obtain an instance of this type by parsing a string. The marked/1 and numbered/1 functions can be used to convert an instance of this type into a string.","ref":"Pinyin.html#t:pinyin_list/0","title":"Pinyin.pinyin_list/0","type":"type"},{"doc":"Representation of a single pinyin syllable. This type represents a single syllable in pinyin. Said otherwise, an instance of this type corresponds to a single Han character. Instances of this type should not be created manually, instead instances can be created from a numbered or marked string through the use of the from_numbered/1 , from_numbered!/1 , from_marked/1 , from_marked!/1 functions or by using the sigil_p/2 sigil.","ref":"Pinyin.html#t:t/0","title":"Pinyin.t/0","type":"type"},{"doc":"Utilities to deal with zhuyin syllables and groups thereof. The main goal of this module is to provide functions to manipulate strings that contain zhuyin words, which are potentially mixed with other content. These strings are represented by the zhuyin_list/0 type. Zhuyin lists can be obtained by parsing a string with the read/2 , read!/2 or sigil_z/2 functions. Afterwards, these lists can be converted into astring representation by using to_string/1 n. A zhuyin_list/0 is a list which contains strings and zhuyin structs ( t/0 ). These structs are used to encode zhuyin syllables; they can be created directly through the use of the from_string/1 or from_string!/1 functions. Like t:zhuyin_lists/0 , t/0 structs can be converted strings through the use of the to_string/1 functions. Additionally both zhuyin_list/0 and zhuyin structs ( t/0 ) can be created from or converted to pinyin structs ( Pinyin.t:t/0 ) using from_pinyin/1 or to_pinyin/1 or","ref":"Zhuyin.html","title":"Zhuyin","type":"module"},{"doc":"Create zhuyin structs from a pinyin struct or list. Examples iex&gt; Zhuyin . from_pinyin ( ~p/nǐhǎo/ ) [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , % Zhuyin { initial : &quot;ㄏ&quot; , final : &quot;ㄠ&quot; , tone : 3 } ] iex&gt; Zhuyin . from_pinyin ( % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 } ) % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 }","ref":"Zhuyin.html#from_pinyin/1","title":"Zhuyin.from_pinyin/1","type":"function"},{"doc":"Create a single zhuyin struct ( t/0 ) from a string. This function can be used to parse a single zhuyin syllable. If parsing fails, an {:error, &lt;remainder of string&gt;} is returned, &lt;remainder of string&gt; contains the part of the string which made parsing fail. Examples iex&gt; Zhuyin . from_string ( &quot;ㄋㄧˇ&quot; ) { :ok , % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } } iex&gt; Zhuyin . from_string ( &quot;ㄋㄧˇㄏㄠˇ&quot; ) { :error , &quot;ㄏㄠˇ&quot; } iex&gt; Zhuyin . from_string ( &quot;ㄋㄧˇhǎo&quot; ) { :error , &quot;hǎo&quot; }","ref":"Zhuyin.html#from_string/1","title":"Zhuyin.from_string/1","type":"function"},{"doc":"Create a single zhuyin struct ( t/0 ) from a string. Like from_string/1 , but returns the result or raises an exception if an error occurred while parsing. Examples iex&gt; Zhuyin . from_string! ( &quot;ㄋㄧˇ&quot; ) % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } iex&gt; Zhuyin . from_string! ( &quot;ㄋㄧˇㄏㄠˇ&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;ㄏㄠˇ&quot; iex&gt; Zhuyin . from_string! ( &quot;ㄋㄧˇhǎo&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;hǎo&quot;","ref":"Zhuyin.html#from_string!/1","title":"Zhuyin.from_string!/1","type":"function"},{"doc":"Read a string and convert it into a list of strings and zhuyin structs. This function reads a string containing zhuyin words mixed with normal text. The output of this function is a list of strings and zhuyin structs. White space and punctuation will be separated from other strings. Parse Modes By default, this function only accepts strings which consists exclusively of zhuyin, whitespace and punctuation. Parsing any text that cannot be interpreted as zhuyin will result in an error: iex&gt; Zhuyin . read ( &quot;ㄋㄧˇㄏㄠˇ!&quot; ) { :ok , [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , % Zhuyin { initial : &quot;ㄏ&quot; , final : &quot;ㄠ&quot; , tone : 3 } , &quot;!&quot; ] } iex&gt; Zhuyin . read ( &quot;ㄋㄧˇㄏㄠˇ, hello!&quot; ) { :error , &quot;hello!&quot; } This behaviour can be tweaked if zhuyin mixed with regular text needs to be parsed; this can be done by passing a mode to this function. There are 3 available modes: :exclusive : The default. Every character (except white space and punctuation) is interpreted as zhuyin. If this is not possible, an error is returned. :words : Any word (i.e. a continuous part of the string that does not contain whitespace or punctuation) is either interpreted as a sequence of zhuyin syllables or as non-pinyin text. If a word contains any characters that cannot be interpreted as zhuyin, the whole word is considered to be non-zhuyin text. This mode does not return errors. :mixed : Any word can contain a mixture of zhuyin and non-zhuyin characters. The read function will interpret anything it can interpret as zhuyin as zhuyin and leaves the other text unmodified. This is mainly useful to mix characters and zhuyin. It is recommend to use the :words mode when possible instead of this mode, as this mode will often parse regular text as zhuyin text. This mode does not return errors. The following examples show the use of all three modes: iex&gt; Zhuyin . read ( &quot;ㄋㄧˇㄏㄠˇ!&quot; , :exclusive ) { :ok , [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , % Zhuyin { initial : &quot;ㄏ&quot; , final : &quot;ㄠ&quot; , tone : 3 } , &quot;!&quot; ] } iex&gt; Zhuyin . read ( &quot;ㄋㄧˇㄏㄠˇ, hello!&quot; , :exclusive ) { :error , &quot;hello!&quot; } iex&gt; Zhuyin . read ( &quot;ㄋㄧˇ好, hello!&quot; , :exclusive ) { :error , &quot;ㄋㄧˇ好, hello!&quot; } iex&gt; Zhuyin . read ( &quot;ㄋㄧˇㄏㄠˇ!&quot; , :words ) { :ok , [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , % Zhuyin { initial : &quot;ㄏ&quot; , final : &quot;ㄠ&quot; , tone : 3 } , &quot;!&quot; ] } iex&gt; Zhuyin . read ( &quot;ㄋㄧˇㄏㄠˇ, hello!&quot; , :words ) { :ok , [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , % Zhuyin { initial : &quot;ㄏ&quot; , final : &quot;ㄠ&quot; , tone : 3 } , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Zhuyin . read ( &quot;ㄋㄧˇ好, hello!&quot; , :words ) { :ok , [ &quot;ㄋㄧˇ好&quot; , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Zhuyin . read ( &quot;ㄋㄧˇㄏㄠˇ!&quot; , :mixed ) { :ok , [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , % Zhuyin { initial : &quot;ㄏ&quot; , final : &quot;ㄠ&quot; , tone : 3 } , &quot;!&quot; ] } iex&gt; Zhuyin . read ( &quot;ㄋㄧˇㄏㄠˇ, hello!&quot; , :mixed ) { :ok , [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , % Zhuyin { initial : &quot;ㄏ&quot; , final : &quot;ㄠ&quot; , tone : 3 } , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] } iex&gt; Zhuyin . read ( &quot;ㄋㄧˇ好, hello!&quot; , :mixed ) { :ok , [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , &quot;好&quot; , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ] }","ref":"Zhuyin.html#read/2","title":"Zhuyin.read/2","type":"function"},{"doc":"Identical to read/2 , but returns the result or a ParseError Examples iex&gt; Zhuyin . read! ( &quot;ㄋㄧˇㄏㄠˇ!&quot; ) [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , % Zhuyin { initial : &quot;ㄏ&quot; , final : &quot;ㄠ&quot; , tone : 3 } , &quot;!&quot; ] iex&gt; Zhuyin . read! ( &quot;ㄋㄧˇㄏㄠˇ, hello!&quot; ) ** (ParseError) Error occurred when attempting to parse: &quot;hello!&quot; iex&gt; Zhuyin . read! ( &quot;ㄋㄧˇㄏㄠˇ, hello!&quot; , :words ) [ % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } , % Zhuyin { initial : &quot;ㄏ&quot; , final : &quot;ㄠ&quot; , tone : 3 } , &quot;, &quot; , &quot;hello&quot; , &quot;!&quot; ]","ref":"Zhuyin.html#read!/2","title":"Zhuyin.read!/2","type":"function"},{"doc":"Sigil to create a zhuyin list or struct. When used without any modifiers, this sigil converts its input into a zhuyin list through the use of read!/2 in :exclusive mode. The w and m modifiers can be used to use :words or :mixed mode respectively. When this sigil is called with the s modifier, a zhuyin struct is created by calling from_string!/1 . Examples iex&gt; ~z/ㄋㄧˇ/ [ % Zhuyin { tone : 3 , initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; } ] iex&gt; ~z/ㄋㄧˇ hello/w [ % Zhuyin { tone : 3 , initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; } , &quot; &quot; , &quot;hello&quot; ] iex&gt; ~z/ㄋㄧˇ好/m [ % Zhuyin { tone : 3 , initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; } , &quot;好&quot; ] iex&gt; ~z/ㄋㄧˇ/s % Zhuyin { tone : 3 , initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; }","ref":"Zhuyin.html#sigil_z/2","title":"Zhuyin.sigil_z/2","type":"macro"},{"doc":"Create pinyin structs from a zhuyin struct or list. Examples iex&gt; Zhuyin . to_pinyin ( ~z/ㄋㄧˇㄏㄠˇ/ ) ~p/nǐhǎo/ iex&gt; Zhuyin . to_pinyin ( % Zhuyin { initial : &quot;ㄋ&quot; , final : &quot;ㄧ&quot; , tone : 3 } ) % Pinyin { initial : &quot;n&quot; , final : &quot;i&quot; , tone : 3 }","ref":"Zhuyin.html#to_pinyin/1","title":"Zhuyin.to_pinyin/1","type":"function"},{"doc":"","ref":"Zhuyin.html#t:t/0","title":"Zhuyin.t/0","type":"type"},{"doc":"List of zhuyin syllables mixed with plain strings.","ref":"Zhuyin.html#t:zhuyin_list/0","title":"Zhuyin.zhuyin_list/0","type":"type"},{"doc":"Error that may be raised when parsing pinyin strings.","ref":"ParseError.html","title":"ParseError","type":"exception"},{"doc":"Flexible, modular utilities for dealing with Chinese characters ( Hanzi ) and Pinyin .","ref":"readme.html","title":"Hanyutils","type":"extras"},{"doc":"Convert Chinese characters (Hanzi) to Pinyin Based on the Unicode Han Database Showing only the most common pronunciation Showing the most common pronunciation for Taiwan (if it differs from the most common pronunciation in mainland China) Showing all available pronunciations Read and manipulate pinyin strings Read both tone-marked and numbered pinyin strings. Supports capitalized and uppercase pinyin words, and supports strings containing pinyin mixed with regular text Convert to either representation (numbered or tone marked) Direct access to the building blocks of the library for more esoteric use cases The following features are planned for a future version of hanyutils: Handle punctuation (。,？,！,...) when translating Han characters Support for 儿 (e.g. translate 这儿 to &quot;zhe'er&quot; instead of &quot;zheer&quot;)","ref":"readme.html#features","title":"Hanyutils - Features","type":"extras"},{"doc":"Add hanyutils to your list of dependencies in mix.exs : def deps do [ { :hanyutils , &quot;~&gt; 0.2.5&quot; } ] end Note that this package automatically generates functions based on a (large) file. Therefore, compiling this dependency takes some time (around a minute on my machine).","ref":"readme.html#installation","title":"Hanyutils - Installation","type":"extras"},{"doc":"If you are dealing with a common use case (e.g. converting all characters in a string to pinyin) it is likely your use case is covered by the Hanyutils module: iex&gt; Hanyutils . to_marked_pinyin ( &quot;你好&quot; ) &quot;nǐhǎo&quot; iex&gt; Hanyutils . to_numbered_pinyin ( &quot;你好&quot; ) &quot;ni3hao3&quot; iex&gt; Hanyutils . to_zhuyin ( &quot;你好&quot; ) &quot;ㄋㄧˇㄏㄠˇ&quot; iex&gt; Hanyutils . characters? ( &quot;你好&quot; ) true iex&gt; Hanyutils . mark_pinyin ( &quot;ni3hao3&quot; ) &quot;nǐhǎo&quot; iex&gt; Hanyutils . number_pinyin ( &quot;nǐhǎo&quot; ) &quot;ni3hao3&quot; iex&gt; Hanyutils . zhuyin_to_numbered_pinyin ( &quot;ㄋㄧˇㄏㄠˇ&quot; ) &quot;ni3hao3&quot; iex&gt; Hanyutils . zhuyin_to_marked_pinyin ( &quot;ㄋㄧˇㄏㄠˇ&quot; ) &quot;nǐhǎo&quot; &quot;ㄋㄧˇㄏㄠˇ&quot; iex&gt; Hanyutils . pinyin_to_zhuyin ( &quot;ni3hǎo&quot; ) &quot;ㄋㄧˇㄏㄠˇ&quot; The Hanyutils module is built on top of the Hanzi , Pinyin , and Zhuyin modules. You can use these lower-level modules directly if your use case is not present in Hanyutils . Feel free to file an issue if you feel like your use case should be covered by the Hanyutils module. As an example, the to_marked_pinyin function shown above could be replaced by the following code: iex&gt; &quot;你好&quot; |&gt; Hanzi . read ( ) |&gt; Hanzi . to_pinyin ( ) |&gt; Pinyin . marked ( ) &quot;nǐhǎo&quot; Alternative versions of this procedure which show all available pronunciations can be written as follows: iex&gt; &quot;重庆&quot; |&gt; Hanzi . read ( ) |&gt; Hanzi . to_pinyin ( &amp; Hanzi . all_pronunciations / 1 ) |&gt; Pinyin . marked ( ) &quot;[ zhòng | chóng | tóng ]qìng&quot; iex&gt; &quot;重庆&quot; |&gt; Hanzi . read ( ) |&gt; Hanzi . to_pinyin ( &amp; Hanzi . all_pronunciations ( &amp;1 , &quot;{&quot; , &quot;;&quot; , &quot;}&quot; ) ) |&gt; Pinyin . marked ( ) &quot;{zhòng;chóng;tóng}qìng&quot;","ref":"readme.html#usage","title":"Hanyutils - Usage","type":"extras"},{"doc":"MIT","ref":"readme.html#license","title":"Hanyutils - License","type":"extras"}]